jenkins-bot has submitted this change and it was merged.

Change subject: Separate testNonAlphabeticalCharactersInSection test
......................................................................


Separate testNonAlphabeticalCharactersInSection test

- The first test fails due to T133276 but the second works well but is
  never reached. Splitting this test ensures the second test to be executed.
- Follow naming convention.

Change-Id: Ib33786dc61d286db53c9d2cdf2882beb55fadaeb
---
M tests/textlib_tests.py
1 file changed, 7 insertions(+), 4 deletions(-)

Approvals:
  Mpaa: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/tests/textlib_tests.py b/tests/textlib_tests.py
index a9be159..151b194 100644
--- a/tests/textlib_tests.py
+++ b/tests/textlib_tests.py
@@ -1,7 +1,7 @@
 # -*- coding: utf-8  -*-
 """Test textlib module."""
 #
-# (C) Pywikibot team, 2011-2015
+# (C) Pywikibot team, 2011-2016
 #
 # Distributed under the terms of the MIT license.
 #
@@ -74,11 +74,14 @@
         self.assertNotContains('enwiki_help_editing', 'Minor_Edits',
                                'section hashes are case-sensitive')
 
-    @unittest.expectedFailure
-    def testNonAlphabeticalCharactersInSection(self):
-        """Test with non-alphabetical chars in section."""
+    @unittest.expectedFailure  # TODO: T133276
+    def test_encoded_chars_in_section(self):
+        """Test encoded chars in section."""
         self.assertContains('enwiki_help_editing', 
'Talk_.28discussion.29_pages',
                             'As used in the TOC')
+
+    def test_underline_characters_in_section(self):
+        """Test with underline chars in section."""
         self.assertContains('enwiki_help_editing', 'Talk_(discussion)_pages',
                             'Understood by mediawiki')
 

-- 
To view, visit https://gerrit.wikimedia.org/r/284684
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: Ib33786dc61d286db53c9d2cdf2882beb55fadaeb
Gerrit-PatchSet: 5
Gerrit-Project: pywikibot/core
Gerrit-Branch: master
Gerrit-Owner: Xqt <i...@gno.de>
Gerrit-Reviewer: John Vandenberg <jay...@gmail.com>
Gerrit-Reviewer: Mpaa <mpaa.w...@gmail.com>
Gerrit-Reviewer: Xqt <i...@gno.de>
Gerrit-Reviewer: jenkins-bot <>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to